﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;

namespace BindingToEnum
{
    public enum ShirtType
    {
        [Display(Name="Dress Shirt")]
        DressShirt,
        [Display(Name="T-Shirt")]
        TShirt,
        CampShirt,
        Polo,
        Jersey
    }

    public class Shirt : INotifyPropertyChanged
    {
        ShirtType type = ShirtType.DressShirt;
        public ShirtType Type
        {
            get { return type; }
            set { SetProperty(ref type, value); }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        protected bool SetProperty<T>(ref T storage, T value, [CallerMemberName] string propertyName = null)
        {
            if (object.Equals(storage, value)) 
                return false;

            storage = value;
            OnPropertyChanged(propertyName);

            return true;
        }

        protected void OnPropertyChanged(string propertyName)
        {
            var eventHandler = this.PropertyChanged;
            if (eventHandler != null)
            {
                eventHandler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion
    }
}
